@@ -1,3 +1,4 @@
+
 module Babel where
 import Static
 import Data.List.Split (splitOn)
@@ -6,8 +7,8 @@ import Data.Maybe
 import Codec.Binary.UTF8.String
 import Data.ByteString
        hiding (take, reverse, dropWhile, takeWhile, drop, map, concat,
-               elem, zip, intercalate, init, tails, isPrefixOf, any, length, null, hPutStr)
-
+               elem, zip, intercalate, init, tails, isPrefixOf, any, length, null,
+               hPutStr)
 
 makeBabel :: Maybe String -> [Char] -> String
 makeBabel b x
@@ -21,6 +22,3 @@ makeBabel b x
           = case splitOn "." x of
                 (z : _) -> z
                 _ -> "en"
-
-
-
