@@ -25,7 +25,7 @@ import MediaWikiParser
 import Network.URL
 import Control.Monad.Except
 import System.Process
- 
+
 notendyet ::
           (String -> ImperativeMonad String) ->
             ParsecT String () ImperativeMonad String ->
@@ -44,7 +44,7 @@ notendyet action sstart eend aku
       <|>
       do a <- anyChar
          notendyet action sstart eend (aku ++ [a])
- 
+
 beginning ::
           (String -> ImperativeMonad String) ->
             ParsecT String () ImperativeMonad String ->
@@ -58,7 +58,7 @@ beginning action sstart eend
       do _ <- sstart
          ne <- notendyet action sstart eend []
          return (ne)
- 
+
 startToEnd ::
            (String -> ImperativeMonad String) ->
              ParsecT String () ImperativeMonad String ->
@@ -73,10 +73,10 @@ startToEnd action sstart eend
       do a <- anyChar
          s <- startToEnd action sstart eend
          return (a : s)
- 
+
 zeroAction :: (Monad m) => t -> t1 -> m [Char]
 zeroAction _ _ = return ""
- 
+
 runAction ::
           String ->
             String ->
@@ -91,7 +91,7 @@ runAction sstart eend action text
        case x of
            Left _ -> return ""
            Right xs -> return xs
- 
+
 chapterAction :: WikiUrl -> String -> ImperativeMonad String
 chapterAction wurl text
   = do pp <- liftIO (getpage d (wurl))
@@ -100,7 +100,7 @@ chapterAction wurl text
                         noinclude wurl ("\n\ndhunparserurl " ++ d ++ "\n\n" ++ p)
            _ -> return ""
   where d = (trim (takeWhile (/= '|') text))
- 
+
 chapterAction2 :: FullWikiUrl -> String -> ImperativeMonad String
 chapterAction2 fu text
   = do pp <- liftIO (getpage d (wurl))
@@ -112,7 +112,6 @@ chapterAction2 fu text
   where e = (trim (takeWhile (/= '|') text))
         d = (removePrintVersion (lemma fu)) ++ "/" ++ e
         wurl = wikiUrl fu
- 
 
 chapterAction3 :: FullWikiUrl -> String -> ImperativeMonad String
 chapterAction3 fu text
@@ -128,38 +127,41 @@ chapterAction3 fu text
 
 includeAction :: WikiUrl -> String -> ImperativeMonad String
 includeAction = qIncludeAction
- 
+
 qIncludeAction :: WikiUrl -> String -> ImperativeMonad String
 qIncludeAction wurl text
-  = if isInfixOf "Vorlage" text then return ("{{"++text++"}}")
-     else  
-      do pp <- (liftIO (print d)) >>liftIO (getpage d (wurl))
+  = if isInfixOf "Vorlage" text then return ("{{" ++ text ++ "}}")
+      else
+      do pp <- (liftIO (print d)) >> liftIO (getpage d (wurl))
          case pp of
-           Just p -> do _ <- addContributors d Nothing
-                        noinclude wurl ("\n\ndhunparserurl " ++ d ++ "\n\n" ++ p)
-           _ -> return ""
+             Just p -> do _ <- addContributors d Nothing
+                          noinclude wurl ("\n\ndhunparserurl " ++ d ++ "\n\n" ++ p)
+             _ -> return ""
   where d = (trim (takeWhile (/= '|') text))
 
 qBookIncludeAction :: WikiUrl -> String -> ImperativeMonad String
 qBookIncludeAction wurl text
-  = if isInfixOf "Vorlage" text then return ("{{"++text++"}}")
-     else  
-      do pp <- (liftIO (print d)) >>liftIO (getBookpage d (wurl))
+  = if isInfixOf "Vorlage" text then return ("{{" ++ text ++ "}}")
+      else
+      do pp <- (liftIO (print d)) >> liftIO (getBookpage d (wurl))
          case pp of
-           Just p -> do _ <- addContributors d Nothing
-                        x <- noinclude wurl ("\n\ndhunparserurl " ++ d ++ "\n\n" ++ p)
-                        st<- get
-                        systempdir <- liftIO getTemporaryDirectory
-                        tempdir <- liftIO $ createTempDirectory systempdir "MediaWiki2LaTeXParser"
-                        liftIO $ Tools.writeFile (tempdir </> "input") x
-                        _ <- liftIO $ system("mediawiki2latex -x "++( Hex.hex (show (fullconfigbase{compile=Just tempdir}))))
-                        t<-liftIO $  Tools.readFile (tempdir </> "output")
-                        put st{loadacu=((read t)++(loadacu st)::[Anything Char])}
-                        return x
-           _ -> return ""
+             Just p -> do _ <- addContributors d Nothing
+                          x <- noinclude wurl ("\n\ndhunparserurl " ++ d ++ "\n\n" ++ p)
+                          st <- get
+                          systempdir <- liftIO getTemporaryDirectory
+                          tempdir <- liftIO $
+                                       createTempDirectory systempdir "MediaWiki2LaTeXParser"
+                          liftIO $ Tools.writeFile (tempdir </> "input") x
+                          _ <- liftIO $
+                                 system
+                                   ("mediawiki2latex -x " ++
+                                      (Hex.hex (show (fullconfigbase{compile = Just tempdir}))))
+                          t <- liftIO $ Tools.readFile (tempdir </> "output")
+                          put st{loadacu = ((read t) ++ (loadacu st) :: [Anything Char])}
+                          return x
+             _ -> return ""
   where d = (trim (takeWhile (/= '|') text))
 
- 
 makeUrl :: String -> String -> String -> [Char]
 makeUrl lang theFam thePage
   = (unify . exportURL)
@@ -183,7 +185,7 @@ makeUrl lang theFam thePage
                 Absolute
                   (Host{protocol = HTTP True, host = "toolserver.org",
                         port = Nothing})}))
- 
+
 langau :: Map String String
 langau
   = fromList
@@ -204,7 +206,7 @@ langau
        ("ce", "\1071\1079\1076\1072\1088\1093\1086"), ("nl", "Auteurs"),
        ("es", "Autores"), ("eu", "Egile"), ("fr", "Auteurs"),
        ("cs", "Autor"), ("br", "Aozer")]
- 
+
 makeHeader :: FullWikiUrl -> Maybe String -> [Char]
 makeHeader fullurl m
   = let mmm = m >>= (\ yy -> Map.lookup yy langau) in
@@ -223,7 +225,7 @@ makeHeader fullurl m
             "\\label{Contributors}\n" ++
               "\\begin{longtable}{rp{0.6\\linewidth}}\n" ++
                 "\\textbf{Edits}&\\textbf{User}\\\\\n"
- 
+
 makeHeaderHTML :: FullWikiUrl -> Maybe String -> [Char]
 makeHeaderHTML fullurl m
   = let mmm = m >>= (\ yy -> Map.lookup yy langau) in
@@ -239,8 +241,7 @@ makeHeaderHTML fullurl m
              _ -> "Contributors")
           ++
           "</h2>\n" ++
-            "<table rules=\"all\">" ++
-                "<tr><td>Edits</td><td>User</td></tr>"
+            "<table rules=\"all\">" ++ "<tr><td>Edits</td><td>User</td></tr>"
 
 makeBody :: (Ord t) => Map t Contributor -> URL -> [Char]
 makeBody m u = concat (map go (sort (toList m)))
@@ -252,17 +253,17 @@ makeBody m u = concat (map go (sort (toList m)))
                 (concat
                    (map chartransforlink (exportURL (u{url_path = (fun (href v))}))))
                   ++ "}{" ++ (concat (map chartrans (name v))) ++ "}\\\\\n"
- 
+
 makeBodyHTML :: (Ord t) => Map t Contributor -> URL -> [Char]
 makeBodyHTML m u = concat (map go (sort (toList m)))
   where fun ('/' : xs) = xs
         fun xs = xs
         go (_, v)
-          = "<tr><td>"++(show (edits v)) ++
-              "</td><td><a href=\"" ++
-                (((exportURL (u{url_path = (fun (href v))}))))
-                  ++ "\">" ++ (concat (map chartrans (name v))) ++ "</a></td></tr>"
-
+          = "<tr><td>" ++
+              (show (edits v)) ++
+                "</td><td><a href=\"" ++
+                  (((exportURL (u{url_path = (fun (href v))})))) ++
+                    "\">" ++ (concat (map chartrans (name v))) ++ "</a></td></tr>"
 
 makeContributors :: Maybe URL -> ImperativeMonad (String, String)
 makeContributors uu
@@ -278,26 +279,26 @@ makeContributors uu
              = case (deepGet2 "html" (parseit minparsers yy)) of
                    ((Environment Tag (TagAttr _ m) _) : []) -> Map.lookup "lang" m
                    _ -> Nothing
-       return (
-         ((makeHeader (fullUrl st) lang) ++
-            (makeBody (myaudict) (url (fullUrl st))) ++
-              "\\end{longtable}\n" ++ "\\pagebreak\n"),(makeHeaderHTML (fullUrl st) lang) ++
-            (makeBodyHTML (myaudict) (url (fullUrl st))) ++"</table>")
- 
+       return
+         (((makeHeader (fullUrl st) lang) ++
+             (makeBody (myaudict) (url (fullUrl st))) ++
+               "\\end{longtable}\n" ++ "\\pagebreak\n"),
+          (makeHeaderHTML (fullUrl st) lang) ++
+            (makeBodyHTML (myaudict) (url (fullUrl st))) ++ "</table>")
+
 parseUrl :: String -> ImperativeMonad FullWikiUrl
 parseUrl u
   = case analyseFull u of
         Just x -> return x
         _ -> throwError (WikiUrlParseError u)
- 
+
 getContributors ::
                 [String] ->
-                  ImperativeMonad
-                    (([(Map String Contributor)], [(Maybe String)]))
+                  ImperativeMonad (([(Map String Contributor)], [(Maybe String)]))
 getContributors u
   = do st <- get
-       stz<- liftIO imperativeStateZero
-       put stz {counter=counter st}
+       stz <- liftIO imperativeStateZero
+       put stz{counter = counter st}
        au <- mapM go u
        newState <- get
        put st
@@ -308,14 +309,14 @@ getContributors u
                sst <- get
                put sst{fullUrl = purl}
                addContributors (lemma purl) (Just (UrlAnalyse.url purl))
- 
+
 addContributors ::
                 [Char] -> Maybe URL -> ImperativeMonad ((Maybe String))
 addContributors theLemma uu
   = do sst <- get
        let st = fullUrl sst
        thetheLemma <- liftIO $ return theLemma
-       thetheHostname <- liftIO $ return (hostname  st)
+       thetheHostname <- liftIO $ return (hostname st)
        thetheUU <- liftIO $ return uu
        au <- (liftIO ((((fun sst)) thetheLemma thetheHostname thetheUU)))
                :: ImperativeMonad ((Map String Contributor, Maybe String))
@@ -323,7 +324,7 @@ addContributors theLemma uu
        lic <- liftIO (((return . snd)) au)
        put sst{audict = auau : (audict sst)}
        return lic
-  where fun ssst lem ho uuu 
+  where fun ssst lem ho uuu
           = do xx <- simpleContributors lem ho uuu ssst
                return (Data.List.foldl runGo2 Map.empty xx, myvalue xx)
         runGo2 mymap (author, theHref, theEdits, _)
@@ -333,7 +334,7 @@ addContributors theLemma uu
           = case yy of
                 [(_, __, _, Just lic)] -> (Just lic)
                 _ -> Nothing
-         
+        
         infun ::
               String ->
                 String -> Integer -> Maybe Contributor -> Maybe Contributor
@@ -341,16 +342,15 @@ addContributors theLemma uu
           = case xx of
                 Nothing -> Just Contributor{name = a, href = h, edits = e}
                 Just old -> Just old{edits = (edits old) + e}
- 
+
 noinclude :: t -> String -> ImperativeMonad [Char]
 noinclude wurl
   = runAction "<noinclude>" "</noinclude>" (zeroAction wurl)
- 
+
 runActions :: FullWikiUrl -> String -> ImperativeMonad String
 runActions fu text
   = do x <- noinclude wurl text
-       y <- runAction "{{Druckversion Kapitel|" "}}" (chapterAction3 fu)
-              x
+       y <- runAction "{{Druckversion Kapitel|" "}}" (chapterAction3 fu) x
        v <- runAction "{{Print entry|" "}}" (chapterAction2 fu) y
        z <- runAction "{{print entry|" "}}" (chapterAction2 fu) v
        a <- runAction "{{Print entry|" "}}" (chapterAction wurl) z
@@ -366,14 +366,13 @@ runActions fu text
        _ <- runAction "{{:" "}}" (qIncludeAction wurl) i
        runAction "{{:" "}}" (qIncludeAction wurl) j
   where wurl = wikiUrl fu
- 
+
 runBookActions :: FullWikiUrl -> String -> ImperativeMonad String
 runBookActions fu text
   = do x <- noinclude wurl text
        runAction "[[" "]]" (qBookIncludeAction wurl) x
   where wurl = wikiUrl fu
 
-
 replacements :: String -> String
 replacements x
   = replace2
@@ -387,7 +386,7 @@ replacements x
          "\n|")
       "{{Fortran:Vorlage: Table}}"
       "prettytable"
- 
+
 loadPlain :: ImperativeState -> Maybe URL -> ImperativeMonad [Char]
 loadPlain st uu
   = let fu = fullUrl st in
@@ -406,31 +405,30 @@ loadBook st uu
                           runBookActions fu p
              _ -> throwError (DownloadError (lemma fu) (exportURL (url fu)))
 
- 
 loadHTML :: ImperativeState -> ImperativeMonad String
 loadHTML st
   = let fu = fullUrl st in
-      do midst<-get
-         (res,newst)<-liftIO (runStateT (runExceptT (loadPlain st (Just (url fu)))) midst)
-         case res of 
-           Right _->put newst
-           _ -> return ()    
+      do midst <- get
+         (res, newst) <- liftIO
+                           (runStateT (runExceptT (loadPlain st (Just (url fu)))) midst)
+         case res of
+             Right _ -> put newst
+             _ -> return ()
          x <- liftIO (geturl2 (exportURL (url fu)))
          return . decode . unpack $ x
- 
 
 loadBookHTML :: ImperativeState -> ImperativeMonad String
 loadBookHTML st
   = let fu = fullUrl st in
-      do midst<-get
-         (res,newst)<-liftIO (runStateT (runExceptT (loadPlain st (Just (url fu)))) midst)
-         case res of 
-           Right _->put newst
-           _ -> return ()    
+      do midst <- get
+         (res, newst) <- liftIO
+                           (runStateT (runExceptT (loadPlain st (Just (url fu)))) midst)
+         case res of
+             Right _ -> put newst
+             _ -> return ()
          x <- liftIO (geturl2 (exportURL (url fu)))
          return . decode . unpack $ x
 
-
 loadMediaWiki :: ImperativeState -> ImperativeMonad [Char]
 loadMediaWiki st
   = let fu = fullUrl st in
@@ -458,9 +456,9 @@ loadMediaWiki st
                                             throwError
                                               (DownloadError (lemma fu) (exportURL (url fu)))
              _ -> throwError (DownloadError (lemma fu) (exportURL (url fu)))
- 
+
 {-DHUN| main function to download images form the wiki. It takes the RunMode as only parameter. In case of HTML the html from the website is loaded. In all other cases the wiki source text is downloaded. In case of ExpandedTemplates the templates are also expanded by mediawiki running on the wiki website DHUN-}
- 
+
 load :: RunMode -> ImperativeMonad String
 load theRunMode
   = do st <- get
