@@ -18,18 +18,18 @@ import Control.Monad
 import Licenses
 import Tools
 import ImperativeState
- 
+
 makeUrl2 :: String -> String -> [Char]
 makeUrl2 theLemma theHost
   = (unify . exportURL)
       (URL{url_path = "w/index.php",
            url_params =
-             [("title", (replace2 theLemma "%" "%25")), ("offset", ""), ("limit", "500000"),
-              ("action", "history")],
+             [("title", (replace2 theLemma "%" "%25")), ("offset", ""),
+              ("limit", "500000"), ("action", "history")],
            url_type =
              Absolute
                (Host{protocol = HTTP True, host = theHost, port = Nothing})})
- 
+
 makeUrl4 :: String -> [Char]
 makeUrl4 uuu
   = fromMaybe uuu
@@ -39,10 +39,10 @@ makeUrl4 uuu
             (unify . exportURL)
               (URL{url_path = (url_path uu),
                    url_params =
-                     [("title", (replace2 ti "%" "%25")), ("offset", ""), ("limit", "500000"),
-                      ("action", "history")],
+                     [("title", (replace2 ti "%" "%25")), ("offset", ""),
+                      ("limit", "500000"), ("action", "history")],
                    url_type = url_type uu}))
- 
+
 makeUrl3 :: String -> String -> [Char]
 makeUrl3 theLemma theHost
   = (unify . exportURL)
@@ -50,7 +50,7 @@ makeUrl3 theLemma theHost
            url_type =
              Absolute
                (Host{protocol = HTTP True, host = theHost, port = Nothing})})
- 
+
 deepGet2 :: [Char] -> [Anything a] -> [Anything a]
 deepGet2 tag ll = concat $ map go ll
   where go (Environment Tag (TagAttr t m) l)
@@ -58,17 +58,16 @@ deepGet2 tag ll = concat $ map go ll
             [Environment Tag (TagAttr tag m) l] ++ (deepGet2 tag l)
         go (Environment _ _ l) = (deepGet2 tag l)
         go _ = []
- 
+
 getLicense :: [Anything Char] -> Maybe [Char]
 getLicense l = (go l)
-  where  
-        go :: [Anything Char] -> Maybe String
+  where go :: [Anything Char] -> Maybe String
         go ll = msum (map (dg ll) licenses)
         dg ll (x, c)
           = case deepGet "a" "href" x ll of
                 (_ : _) -> Just c
                 _ -> Nothing
- 
+
 getAuthor :: [Anything Char] -> Maybe [Anything Char]
 getAuthor x = listToMaybe (concat (map go (deepGet2 "tr" x)))
   where go (Environment _ _ l)
@@ -79,10 +78,12 @@ getAuthor x = listToMaybe (concat (map go (deepGet2 "tr" x)))
                                  _ -> []
                   _ -> []
         go _ = []
- 
+
 simpleContributors ::
                    [Char] ->
-                     [Char] -> Maybe URL -> ImperativeState-> IO [(String, String, Int, Maybe String)]
+                     [Char] ->
+                       Maybe URL ->
+                         ImperativeState -> IO [(String, String, Int, Maybe String)]
 simpleContributors theLemma theHost uu st
   = do let theUrl3
              = case uu of
@@ -116,66 +117,68 @@ simpleContributors theLemma theHost uu st
        let y = decodeString yy
        let x = decodeString xx
        let dd
-             = ((deepGet "a" "class" "new mw-userlink" (parseit minparsers x))++(deepGet "a" "class" "mw-userlink" (parseit minparsers x))) ::
-                 [Anything Char]
+             = ((deepGet "a" "class" "new mw-userlink" (parseit minparsers x))
+                  ++ (deepGet "a" "class" "mw-userlink" (parseit minparsers x)))
+                 :: [Anything Char]
        let ll = (filter pre (map go dd))
        let n = (nub ll) :: [(String, String)]
        let out = map go2 (zip (map (count ll) n) n)
        let ht = (parseit htmlminparsers y)
        case (getAuthor ht) of
            Just zz -> return
-                        [(fst (treeToLaTeX3 zz initialState{urld = analyseNetloc (hostname . fullUrl $ st)}), "", 1 :: Int, getLicense ht)]
+                        [(fst
+                            (treeToLaTeX3 zz
+                               initialState{urld = analyseNetloc (hostname . fullUrl $ st)}),
+                          "", 1 :: Int, getLicense ht)]
            _ -> return out
-
-  where  
-        go :: Anything Char -> (String, String)
+  where go :: Anything Char -> (String, String)
         go (Environment Tag (TagAttr _ m) l)
           = ((shallowFlatten (deepFlatten l)), findWithDefault "" "href" m)
         go _ = ("", "")
         go2 (c, (a, h)) = (a, h, c, Nothing)
- 
+
 count :: (Eq a) => [a] -> a -> Int
 count l s = length (filter (== s) l)
- 
+
 pre :: (String, String) -> Bool
 pre s
   = case (runParser ipaddr () "" (fst s)) of
         Right _ -> False
         Left _ -> True
- 
+
 intdigit :: Parser Int
 intdigit
   = do a <- digit
        case reads [a] of
            [(i, [])] -> return i
            _ -> pzero
- 
+
 ipnum3 :: ParsecT String () Identity Int
 ipnum3
   = do a <- intdigit
        b <- intdigit
        c <- intdigit
        return (a * 100 + b * 10 + c)
- 
+
 ipnum2 :: ParsecT String () Identity Int
 ipnum2
   = do a <- intdigit
        b <- intdigit
        return (a * 10 + b)
- 
+
 ipnum1 :: Parser Int
 ipnum1 = do intdigit
- 
+
 ipnum :: ParsecT [Char] () Identity ()
 ipnum
   = do n <- (try (ipnum3)) <|> (try (ipnum2)) <|> ipnum1
        if ((n <= 255) && (n >= 0)) then return () else pzero
- 
+
 ipaddr ::
        Text.Parsec.Prim.ParsecT [Char] () Data.Functor.Identity.Identity
          ()
 ipaddr = try (ipv4addr) <|> ipv6addr
- 
+
 ipv4addr ::
          Text.Parsec.Prim.ParsecT [Char] () Data.Functor.Identity.Identity
            ()
@@ -188,7 +191,7 @@ ipv4addr
        _ <- char '.'
        _ <- ipnum
        return ()
- 
+
 ipv6num ::
         Text.Parsec.Prim.ParsecT [Char] () Data.Functor.Identity.Identity
           ()
@@ -199,7 +202,7 @@ ipv6num
          _ <- try (hexDigit) <|> return '0'
          _ <- try (hexDigit) <|> return '0'
          return ()
- 
+
 ipv6addr ::
          Text.Parsec.Prim.ParsecT [Char] () Data.Functor.Identity.Identity
            ()
